# PricingSystemEnum

* `coefficient_price` - Coefficient price * `ton_price` - Ton price * `mileage_price` - Mileage price * `load_price` - Load price

## Enum

* `COEFFICIENT_PRICE` (value: `'coefficient_price'`)

* `TON_PRICE` (value: `'ton_price'`)

* `MILEAGE_PRICE` (value: `'mileage_price'`)

* `LOAD_PRICE` (value: `'load_price'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


